==> valknut_0.3.13.orig.tar.gz: valknut-0.3.13/valknut/dcedittransfer.h <==
/***************************************************************************
                          dcedittransfer.h  -  description
                             -------------------
    begin                : Don Dez 5 2002
    copyright            : (C) 2002 by Mathias Kster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCEDITTRANSFER_H
#define DCEDITTRANSFER_H

#include <qwidget.h>

#include <dclib/core/clist.h>
#include <dclib/dcobject.h>

#include <DCDialogEditTransfer.h>

/**
  *@author Mathias Kster
  */

class DCEditTransfer : public DCDialogEditTransfer  {
Q_OBJECT

public: 
	/** construtor */
	DCEditTransfer(QWidget *parent=0, const char *name=0);
	/** destructor */
	virtual ~DCEditTransfer();

	/** */
	void InitDocument();
	/** */
	void Init(QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );

private:
	/** */
	CList<DCHubObject> * m_pHubObjectList;

private slots:
	/** */
	void slotKnownHubsChange( const QString & );
};

#endif

==> valknut_0.4.9.orig.tar.gz: valknut-0.4.9/valknut/dcedittransfer.h <==
/***************************************************************************
                          dcedittransfer.h  -  description
                             -------------------
    begin                : Don Dez 5 2002
    copyright            : (C) 2002 by Mathias Küster
    email                : mathen@users.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DCEDITTRANSFER_H
#define DCEDITTRANSFER_H

#include <qwidget.h>

#include <dclib/core/clist.h>
class DCHubObject;

#include "DCDialogEditTransfer.h"

/**
  *@author Mathias Küster
  */

class DCEditTransfer : public QDialog, public Ui::DCDialogEditTransfer  {
Q_OBJECT

public: 
	/** construtor */
	DCEditTransfer( QWidget * parent = 0 );
	/** destructor */
	virtual ~DCEditTransfer();

	/** */
	void Init(QString & nick, QString & hubname, QString & hubhost, CList<DCHubObject> * list );

private:
	/** */
	CList<DCHubObject> * m_pHubObjectList;

private slots:
	/** */
	void slotKnownHubsChange( const QString & );
};

#endif
